@@ -8,8 +8,8 @@ from itle.ddk.ddk_channel_type import DDKChannelType2
 class DDKPidAuthorityRequest(RestApi):
     """查询是否完成备案"""
 
-    def __init__(self, aio_http: aiohttp, domain: str, port: int):
-        super(DDKPidAuthorityRequest, self).__init__(aio_http, domain, port)
+    def __init__(self, aio_http: aiohttp, domain: str, port: int, token: str):
+        super(DDKPidAuthorityRequest, self).__init__(aio_http, domain, port, token)
 
         self.ddk_pid = None
         self.custom_params = None
@@ -24,11 +24,10 @@ class DDKPidAuthorityRequest(RestApi):
 class DDKPidAuthorityUrlRequest(RestApi):
     """创建备案链接"""
 
-    def __init__(self, aio_http: aiohttp, domain: str, port: int):
-        super(DDKPidAuthorityUrlRequest, self).__init__(aio_http, domain, port)
-        self.ddk_pid_list = None
+    def __init__(self, aio_http: aiohttp, domain: str, port: int, token: str):
+        super(DDKPidAuthorityUrlRequest, self).__init__(aio_http, domain, port, token)
+        self.user_id = None
         self.channel_type: [int] = DDKChannelType2.GENERATE_BIND_URL.value
-        self.custom_params = None
         self.amount = None
         self.scratch_card_amount = None
         self.diy_one_yuan_param = None
