@@ -5,8 +5,8 @@ from itle.base import RestApi
 
 
 class DDKCatsRequest(RestApi):
-    def __init__(self, aio_http: aiohttp, domain: str, port: int):
-        super(DDKCatsRequest, self).__init__(aio_http, domain, port)
+    def __init__(self, aio_http: aiohttp, domain: str, port: int, token: str):
+        super(DDKCatsRequest, self).__init__(aio_http, domain, port, token)
         self.parent_cat_id = None
 
     def get_api_uri(self):
