@@ -5,10 +5,8 @@ from itle.base import RestApi
 
 
 class DDKPidQueryRequest(RestApi):
-    def __init__(self, aio_http: aiohttp, domain: str, port: int):
-        super(DDKPidQueryRequest, self).__init__(aio_http, domain, port)
-
-        self.ddk_pid_list = None
+    def __init__(self, aio_http: aiohttp, domain: str, port: int, token: str):
+        super(DDKPidQueryRequest, self).__init__(aio_http, domain, port, token)
         self.page_index = None
         self.page_size = None
         self.status = None
@@ -21,9 +19,8 @@ class DDKPidQueryRequest(RestApi):
 
 
 class DDKPidCreateRequest(RestApi):
-    def __init__(self, aio_http: aiohttp, domain: str, port: int):
-        super(DDKPidCreateRequest, self).__init__(aio_http, domain, port)
-
+    def __init__(self, aio_http: aiohttp, domain: str, port: int, token: str):
+        super(DDKPidCreateRequest, self).__init__(aio_http, domain, port, token)
         self.media_id = None
         self.pid_name_list = None
         self.count = None
